Skip to contents

An extension receives RhoExtensionAPI and registers typed tools, providers, commands, or event handlers. rho_dispatch_event() normalizes an event pipeline to a task so asynchronous handlers remain part of the agent control flow.